==> haskell-conduit-extra-1.3.8-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-extra
version:              1.3.8
visibility:           public
id:                   conduit-extra-1.3.8-ocqV3ZQIM7JZjciPRh2Zy
key:                  conduit-extra-1.3.8-ocqV3ZQIM7JZjciPRh2Zy
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.

category:             Data, Conduit
abi:                  f0c382d65ce7c5851d1a74d02617335a
exposed:              True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib

import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-extra
hs-libraries:         HSconduit-extra-1.3.8-ocqV3ZQIM7JZjciPRh2Zy
depends:
    async-2.2.5-JGCoQdxZuXN6RYZ81Kl1U4
    attoparsec-0.14.4-IXbcbJGX0cBC8WVvSy4ntj base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-6EN3TiAZvJYIfvMY9NMvKR
    directory-1.3.7.1 filepath-1.4.2.2
    network-3.1.4.0-KAEk2uZxmO9GA8hoXz0jL7
    primitive-0.9.1.0-IjHZubyRsLN7SdbALfq7Lq process-1.6.18.0
    resourcet-1.2.6-98QeMzdnC7kQabpsrpmbK stm-2.5.1.0
    streaming-commons-0.2.3.0-CvQm1m2y9fJH6ySXW21rvR text-2.0.2
    transformers-0.5.6.2 typed-process-0.2.13.0-Leb0h37kAY22dU5VGScI0N
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock

haddock-html:         /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-extra-1.3.8-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-extra
version:              1.3.8
visibility:           public
id:                   conduit-extra-1.3.8-19lmWL4nfT7KBh5mbFf6Y1
key:                  conduit-extra-1.3.8-19lmWL4nfT7KBh5mbFf6Y1
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.

category:             Data, Conduit
abi:                  36368c7a208ceb0e8d84ffa07278caf1
exposed:              True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib

import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-extra
hs-libraries:         HSconduit-extra-1.3.8-19lmWL4nfT7KBh5mbFf6Y1
depends:
    async-2.2.5-FyJFxj28VNy7uaj8UqY8bG
    attoparsec-0.14.4-H7aeDSX4mnyDRaYndD48j5 base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-L9TggbIlNiTCDF5rGZVa9g
    directory-1.3.7.1 filepath-1.4.2.2
    network-3.1.4.0-1eoJcyQnoY08famP5jSKP3
    primitive-0.9.1.0-9RF5UPzNfxF3rXGzmAaAQ3 process-1.6.18.0
    resourcet-1.2.6-FSCUiwlyZ0b8fgSbQ2cm0c stm-2.5.1.0
    streaming-commons-0.2.3.0-DmxhJQdbLf6K4r7XSbVDwb text-2.0.2
    transformers-0.5.6.2 typed-process-0.2.13.0-9GJUv4K4MuKASOrgmAVjtC
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock

haddock-html:         /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
